@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
+import os
 
-from ml_benchmark.metrics_storage import MetricsStorage
+from ml_benchmark.config import MetricsStorageConfig
 
 
 class Objective(ABC):
@@ -9,9 +10,6 @@ class Objective(ABC):
     Interface for a training, validation and test procedure of a model.
     """
 
-    # need possibility to set dynamically - public IP if ssh connect
-    metrics_storage_address = MetricsStorage.connection_string # create on object init
-
     @abstractmethod
     def train(self):
         pass
